powered by
Takes structure data file (SDF) of candidate drug and predicts its drug class using deterministic model.
drug.class.deterministic("sdf")
input sdf file
predicted drug class of the candidate drug by deterministic model
uCAREChemSuiteCLI
# NOT RUN { { example.class.deterministic<- system.file('extdata/example.sdf', package="uCAREChemSuiteCLI") drug.class.deterministic(example.class.deterministic) } # }
Run the code above in your browser using DataLab