Learn R Programming

uCAREChemSuiteCLI (version 0.2.0)

drug.class.stochastic: drug.class.stochastic

Description

Takes structure data file (SDF) of candidate drug, Nearest Neighbor value and threshold similarity score to predict its drug class using stochastic model.

Usage

drug.class.stochastic("sdf", "NearestNeighbor", "Threshold")

Arguments

sdf

input sdf file

NearestNeighbor

Nearest Neighbor = 1, 3

Threshold

Threshold = 0.25, 0.3, 0.35, 0.4

Value

Predicted drug class of the candidate drug using Nearest Neighbor algorithm

Details

uCAREChemSuiteCLI

Examples

Run this code
# NOT RUN {
{
example.class.stochastic<- system.file('extdata/example.sdf', package="uCAREChemSuiteCLI")
drug.class.stochastic(example.class.stochastic,"3","0.25")
}
# }

Run the code above in your browser using DataLab