Learn R Programming

uCAREChemSuiteCLI (version 0.2.0)

drug.resistome.deterministic: drug.resistome.deterministic

Description

Takes structure data file (SDF) of candidate drug to predicts its resistome using deterministic model.

Usage

drug.resistome.deterministic("sdf", "Organism")

Arguments

sdf

input sdf file

Organism

Escherichia coli = 1, Pseudomonas aeruginosa = 2

Value

Predicted resistome of the candidate drug using deterministic model

Details

uCAREChemSuiteCLI

Examples

Run this code
# NOT RUN {
{
example.resistome.deterministic<- system.file('extdata/example.sdf', package="uCAREChemSuiteCLI")
drug.resistome.deterministic(example.resistome.deterministic, "1")
}
# }

Run the code above in your browser using DataLab