Learn R Programming

uCAREChemSuiteCLI (version 0.2.0)

drug.resistome.stochastic: drug.resistome.stochastic

Description

Takes structure data file (SDF) of candidate drug to predict its resistome using stochastic model.

Usage

drug.resistome.stochastic("sdf", "NearestNeighbor", "Threshold", "Organism")

Arguments

sdf

input sdf file

NearestNeighbor

Nearest Neighbor = 1, 3

Threshold

Threshold = 0.25, 0.3, 0.35, 0.4

Organism

Escherichia coli = 1, Pseudomonas aeruginosa = 2

Value

Predicted resistome of the candidate drug using Nearest Neighbor algorithm

Details

uCAREChemSuiteCLI

Examples

Run this code
# NOT RUN {
{
example.resistome.stochastic<- system.file('extdata/example.sdf', package="uCAREChemSuiteCLI")
drug.resistome.stochastic(example.resistome.stochastic, "3", "0.25", "1")
}
# }

Run the code above in your browser using DataLab