powered by
Takes structure data file (SDF) of candidate drug, Nearest Neighbor value and threshold similarity score to predict its drug class using stochastic model.
drug.class.stochastic("sdf", "NearestNeighbor", "Threshold")
input sdf file
Nearest Neighbor = 1, 3
Threshold = 0.25, 0.3, 0.35, 0.4
Predicted drug class of the candidate drug using Nearest Neighbor algorithm
uCAREChemSuiteCLI
# NOT RUN { { example.class.stochastic<- system.file('extdata/example.sdf', package="uCAREChemSuiteCLI") drug.class.stochastic(example.class.stochastic,"3","0.25") } # }
Run the code above in your browser using DataLab