powered by
Takes structure data file (SDF) of candidate drug to predicts its resistome using deterministic model.
drug.resistome.deterministic("sdf", "Organism")
input sdf file
Escherichia coli = 1, Pseudomonas aeruginosa = 2
Predicted resistome of the candidate drug using deterministic model
uCAREChemSuiteCLI
# NOT RUN { { example.resistome.deterministic<- system.file('extdata/example.sdf', package="uCAREChemSuiteCLI") drug.resistome.deterministic(example.resistome.deterministic, "1") } # }
Run the code above in your browser using DataLab