powered by
Takes structure data file (SDF) of candidate drug to predict its resistome using stochastic model.
drug.resistome.stochastic("sdf", "NearestNeighbor", "Threshold", "Organism")
input sdf file
Nearest Neighbor = 1, 3
Threshold = 0.25, 0.3, 0.35, 0.4
Escherichia coli = 1, Pseudomonas aeruginosa = 2
Predicted resistome of the candidate drug using Nearest Neighbor algorithm
uCAREChemSuiteCLI
# NOT RUN { { example.resistome.stochastic<- system.file('extdata/example.sdf', package="uCAREChemSuiteCLI") drug.resistome.stochastic(example.resistome.stochastic, "3", "0.25", "1") } # }
Run the code above in your browser using DataLab